/*
    Copyright (C) 2011 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EFILEINFO_H
#define EFILEINFO_H

#include "eglobal.h"

#include <QString>

/**
	* @brief Data about a file handled by EFileService.
	*/
class E_CORE_EXPORT EFileInfo
{
	public:
		EFileInfo();
		
		/**
			* @brief Returns true, if this EFileInfo contains valid data.
			* 
			* The data is valid, if the id() and the name() is not empty.
			*/
		bool isValid() const;
		
		void setId(QString id);
		/**
			* @brief A unique internal identifier.
			* 
			*/
		QString id() const;
		void setName(QString name);
		/**
			* @brief A human readable identifier.
			* 
			* May be the same as the identifier, but can also
			* be different.
			*/
		QString name() const;
		void setSize(quint64 size);
		/**
			* @brief The size of the file in bytes.
			*/
		quint64 size();
		void setMimeType(QString mimeType);
		/**
			* @brief The MimeType of the file.
			*/
		QString mimeType() const;
		
		bool operator== (const EFileInfo &info) const;
		bool operator== (const QString &id) const;
		bool operator!= (const EFileInfo &info) const;
		bool operator!= (const QString &id) const;
		
	private:
		QString myId, myName, myMimeType;
		quint64 mySize;
};

#endif // EFILEINFO_H
