/*
		Copyright (C) 2010 - 2013 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ELOGOBJECT_H
#define ELOGOBJECT_H

#include "eobject.h"
#include "eglobal.h"

class EWidget;
class ELogObjectPrivate;

/**
	* @brief Creates a QDockWidget and collects all errors, warnings and information.
	*
	* The object, where the warnings, errors and information are collected from, can be
	* set with setup(EObject*) or setup(EWidget*).
	* If you want to catch all qDebug(), qWarning(), qCritical() and qFatal() outputs,
	* call ELogObject() with first argument set to true, to install this object
	* as a message handler.
	*
	* To log to a file instead of the log widget, specify the file path as first parameter
	* of init().
	*
	* @note The message "This application has requested the Runtime to terminate it in an unusual way."
	*       appearing when qFatal() is used, is caused by calling abort(). This is not an error of this class.
	*
	* @see messageHandler()
	*/
class E_CORE_EXPORT ELogObject : public EObject
{
	Q_OBJECT
	public:
		ELogObject(bool installMessageHandler, QObject *parent = NULL);
		~ELogObject();
		/**
			* @brief Set's up the log object.
			*
			* To log to a file, specifiy the log file file path with @p filePath.
			* If empty, it is logged to a QTextEdit in an QDockWidget.
			*/
		void init(QString filePath = QString());
		void setup(EObject *object);
		void setup(EWidget *object);
		/**
			* @brief Used to fetch the messages of qDebug(), qWarning(), qCritical() and qFatal().
			*
			* To install it, just call ELogObject() with first argument set to true.
			*/
#if QT_VERSION >= 0x050000
        static void messageHandler(QtMsgType type, const QMessageLogContext &content, const QString &msg);
#else
		static void messageHandler(QtMsgType type, const char *msg);
#endif

	signals:
#if QT_VERSION >= 0x050000
        void addMessage(QtMsgType type, const QMessageLogContext &content, const QString msg);
#else
        void addMessage(QtMsgType type, const QString msg);
#endif

	private:
#if QT_VERSION >= 0x050000
        void populateMessage(QtMsgType type, const QMessageLogContext &content, const QString msg);
#else
        void populateMessage(QtMsgType type, const QString msg);
#endif

		static ELogObject *self;
		ELogObjectPrivate *logger;
		bool installedAsMessageHandler;
};

#endif // ELOGOBJECT_H
