/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/


#ifndef EMODULESTATEDIALOG_H
#define EMODULESTATEDIALOG_H

#include "edialog.h"
#include "eglobal.h"

class EModuleListWidgetItem;
class EModuleStateWidget;

namespace Ui {
	class EModuleStateDialog;
};

#include <QMap>

/**
	* @brief Dialog to display EModuleStateWidgets.
	*
	* Use addModuleState() to add a new EModuleStateWidget
	* to the tab widget. You may connect to the provided signals
	* to reload, unload and load plugins, if the user
	* click's on the provided buttons.
	*/
class E_CORE_EXPORT EModuleStateDialog : public EDialog
{
	Q_OBJECT
	Q_FLAGS(ActiveButtons)
	public:
		/**
			* @brief Enum to identify which buttons should be enabled.
			*
			* If no button is specified, all buttons are off.
			* If EModuleStateDialog::Load and EModuleStateDialog::Unload is
			* chosen, reloadAll button is also activated.
			*/
		enum ActiveButton {
			Load = 0x01,		/**< Load buttun is enabled */
			Unload = 0x02,	/**< Unload button is enabled */
		};
		Q_DECLARE_FLAGS(ActiveButtons, ActiveButton)
		Q_ENUMS(ActiveButton)
	
    EModuleStateDialog(QWidget* parent = 0, Qt::WindowFlags flags = 0);
		
		EModuleStateWidget *addModuleState(EngSaS::ModuleListWidgetItems protocol, QString title,
																			 ActiveButtons enabledButtons = ActiveButtons());
		
	private slots:
		void tabChanged(int index);
		void itemClicked ( EModuleListWidgetItem *item );
		void loadButton();
		void unloadButton();
		void reloadAllButton();

	private:
		EModuleListWidgetItem *activeItem;
		Ui::EModuleStateDialog *ui;
		QMap<int, ActiveButtons> activeButtons;
	
	signals:
		void reloadPlugins();
    void unload ( EModuleListWidgetItem* item );
    void loadPlugin ( EModuleListWidgetItem* item, bool emitSetupWizard );
};

Q_DECLARE_OPERATORS_FOR_FLAGS(EModuleStateDialog::ActiveButtons)

#endif // EMODULESTATEDIALOG_H
