/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/


#ifndef ENETWORKACCESSMANAGER_H
#define ENETWORKACCESSMANAGER_H

#include "eglobal.h"
#include <QNetworkAccessManager>

/**
	* @brief Provides a easier way to manipulate the User-Agent string.
	* 
	* This is useful to monitor the actions on your webserver.
	*/
class E_CORE_EXPORT ENetworkAccessManager : public QNetworkAccessManager
{
	Q_OBJECT
	public:
    inline ENetworkAccessManager(QObject* parent = 0) : QNetworkAccessManager(parent){ };
		/**
			* @brief Overload of QNetworkAccessManager::get() to manipulate the User-Agent.
			* 
			* It changes the User-Agent to ApplicationName-Version. If @p appName is empty,
			* QApplication::applicationName() is used. If @p version is also empty,
			* QApplication::applicationVersion() is appended to the application name.
			*/
		QNetworkReply *get (QNetworkRequest &request, QString appName = QString(), QString version = QString());
		/**
			* @brief See get().
			*/
		QNetworkReply * post (QNetworkRequest &request, const QByteArray &data, QString appName = QString(), QString version = QString());
};

#endif // ENETWORKACCESSMANAGER_H
