/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ESETTINGSWIDGET_H
#define ESETTINGSWIDGET_H

#include "eglobal.h"
#include "ewidget.h"

class ESettingsModelItem;

/**
  * @brief The base class of the all widgets used to display settings at the ESettingsDialog
  */
class E_CORE_EXPORT ESettingsWidget : public EWidget
{
	Q_OBJECT
	Q_PROPERTY(QString name READ name WRITE setName)
	public:
		inline ESettingsWidget ( QWidget *parent = 0, Qt::WindowFlags flags = 0 ) : EWidget ( parent, flags ){};
		ESettingsWidget ( QString name, QWidget *parent = 0, Qt::WindowFlags flags = 0 );
		/**
			* Used to display the name of the tab
			*/
		QString name() const;
		void setName ( QString newName );
		/**
			* @brief Converts the ESettingsWidget into an ESettingsModelItem.
			* 
			* The name of the ESettingsModelItem will be set to name().
			* @note Do not delete the ESettingsWidget afterwards, because the
			*       ESettingsModelItem will be deleted also.
			*/
		ESettingsModelItem* toModelItem();

	public slots:
		/**
			* @brief Called to save all presented settings.
			*
			* Possible error message should be stored into @p error.
			* @return true on success and false if settings could not be saved.
			*/
		virtual bool saveSettings(QString &error);

	protected:
		QString myName;
};

#endif
