/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ESQLDATABASE_H
#define ESQLDATABASE_H

#include "eglobal.h"

#include <QSqlDatabase>

namespace KWallet {
	class Wallet;
}

/**
	* @brief An improved QSqlDatabase class.
	* @ingroup SQL
	*/
class E_CORE_EXPORT ESqlDatabase : public QSqlDatabase
{
	public:
		ESqlDatabase ();
		ESqlDatabase ( const QSqlDatabase & other );
		ESqlDatabase ( const QString &useType );
    ~ESqlDatabase();

		bool loadAndCheckSettings(QString username, QString host, QString dbName,
																		QString newType, QString passwd);
		void setType(QString name);
		QString type();
		
// 		bool open();
		QStringList tables ( QSql::TableType type = QSql::Tables ) const;
		
// 		static MSqlDatabase addDatabase(const QString &useType, const QString &connectionName = QString());
		static bool checkSettings();
		/**
			* should be used thorughout the whole project,
			* because the orignal database function opens the connection automatically,
			* therefore bool closeDB = !db.isOpen() isn't working and transactions through
			* more than one database() does not work too!
			*/
		static ESqlDatabase database(QString connectionName = QLatin1String( defaultConnection ));
		
	private:
		/**
			* @return List of table names inside selected database (@see databaseName )
			*/
		QStringList tableList() const;
		/**
			* right now only default implementation will be called
			* @todo must be implemented
			*/
		QStringList systemTableList() const;
		/**
			* @return List of view names inside selected database (@see databaseName )
			*/
		QStringList viewList() const;
		/**
			* @return a combined list of all three other lists
			*/
		QStringList allList() const;
		
		void init();
		
		QString myType;
		KWallet::Wallet *wallet;
};

#endif // ESQLDATABASE_H
