/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EXMLPARSERITEM_H
#define EXMLPARSERITEM_H

#include "eglobal.h"

class EXmlItem;
class EXmlModel;

#include <QString>
#include <QDomElement>
#include <QMap>

/**
	* @brief Used to connect tagNames to EXmlItem's.
	* 
	* The given callback function is used to create
	* an instance of the connected EXmlItem Implementation when load is called.
	* The pointer to EXmlModel is used to provide it to the create callback function.
	*
	* @note tagName() is turned into lowercase.
	*/
class E_CORE_EXPORT EXmlParserItem
{
	public:
		/**
			* @p tagName is the name of the tag, which can be handle
			* @p callback is the function, which can be used to create an instance of the EXmlItem implementation, which can handle @p tagName
			* @p model is the pointer the EXmlModel, which should be passed to @p callback, if called.
			*/
		EXmlParserItem(QString tagName, EXmlItem* (*callback)(EXmlModel*), EXmlModel *model);
		inline ~EXmlParserItem(){}

		/**
			* Calls the callback function to create an instance of EXmlItem. Afterwards it sets the
			* @p parent of the returned item and calls EXmlItem::load() afterwards to load the XML data.
			* The parameter @p model contains a pointer to the model, where the created EXmlItem is used in.
			*/
		EXmlItem *load(QDomElement element, EXmlItem *parent, QMap<QString, EXmlParserItem *> parser);
		QString tagName() const;		
		
	private:
		QString myTagName;
		EXmlItem *(*callback)(EXmlModel*);
		EXmlModel *model;
};

#endif // EXMLPARSERITEM_H
