/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EXMLSTANDARDROOTITEM_H
#define EXMLSTANDARDROOTITEM_H

#include "exmlitem.h"
#include "eglobal.h"

class EXmlModel;

/**
	* @brief A standard root item for EXmlModels.
	*
	* It does nothing else than handling childs.
	* To use it, subclass it and implement as follows:
	* @code
	* class YourRootItem ; public EXmlStandardRootItem
	*   Q_OBJECT
	*   public:
	*     Q_INVOKABLE inline YourRootItem() : EXmlStandardRootItem("myTagName") { }
	*     static inline EXmlItem *create(EXmlModel*){ return new YourRootItem(); }
	* };
	* @endcode
	* Note the Q_INVOKABLE constructor, which is used by the copy() function to
	* create new instances of your subclass.
	*/
class E_CORE_EXPORT EXmlStandardRootItem : public EXmlItem
{
	Q_OBJECT
	public:
		inline EXmlStandardRootItem(QString tagName) : EXmlItem(tagName, NULL) { }

		QVariant data(int column, int role = Qt::DisplayRole) const;
		bool load(const QDomElement element, QMap< QString, EXmlParserItem* > parser);
		bool save(QDomElement& useElem);
		EXmlItem *copy() const;
};

#endif // EXMLSTANDARDROOTITEM_H
